# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ....admin.participant.v30 import active_contract_pb2 as _active_contract_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PartyReplicationTargetParticipantMessage(_message.Message):
    __slots__ = ("initialize", "send_acs_up_to")
    class Initialize(_message.Message):
        __slots__ = ("initial_contract_ordinal_inclusive",)
        INITIAL_CONTRACT_ORDINAL_INCLUSIVE_FIELD_NUMBER: _ClassVar[int]
        initial_contract_ordinal_inclusive: int
        def __init__(self, initial_contract_ordinal_inclusive: _Optional[int] = ...) -> None: ...
    class SendAcsUpTo(_message.Message):
        __slots__ = ("max_contract_ordinal_inclusive",)
        MAX_CONTRACT_ORDINAL_INCLUSIVE_FIELD_NUMBER: _ClassVar[int]
        max_contract_ordinal_inclusive: int
        def __init__(self, max_contract_ordinal_inclusive: _Optional[int] = ...) -> None: ...
    INITIALIZE_FIELD_NUMBER: _ClassVar[int]
    SEND_ACS_UP_TO_FIELD_NUMBER: _ClassVar[int]
    initialize: PartyReplicationTargetParticipantMessage.Initialize
    send_acs_up_to: PartyReplicationTargetParticipantMessage.SendAcsUpTo
    def __init__(self, initialize: _Optional[_Union[PartyReplicationTargetParticipantMessage.Initialize, _Mapping]] = ..., send_acs_up_to: _Optional[_Union[PartyReplicationTargetParticipantMessage.SendAcsUpTo, _Mapping]] = ...) -> None: ...

class PartyReplicationSourceParticipantMessage(_message.Message):
    __slots__ = ("acs_batch", "end_of_acs")
    class AcsBatch(_message.Message):
        __slots__ = ("contracts",)
        CONTRACTS_FIELD_NUMBER: _ClassVar[int]
        contracts: _containers.RepeatedCompositeFieldContainer[_active_contract_pb2.ActiveContractOld]
        def __init__(self, contracts: _Optional[_Iterable[_Union[_active_contract_pb2.ActiveContractOld, _Mapping]]] = ...) -> None: ...
    class EndOfACS(_message.Message):
        __slots__ = ()
        def __init__(self) -> None: ...
    ACS_BATCH_FIELD_NUMBER: _ClassVar[int]
    END_OF_ACS_FIELD_NUMBER: _ClassVar[int]
    acs_batch: PartyReplicationSourceParticipantMessage.AcsBatch
    end_of_acs: PartyReplicationSourceParticipantMessage.EndOfACS
    def __init__(self, acs_batch: _Optional[_Union[PartyReplicationSourceParticipantMessage.AcsBatch, _Mapping]] = ..., end_of_acs: _Optional[_Union[PartyReplicationSourceParticipantMessage.EndOfACS, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
import datetime

from . import state_service_pb2 as _state_service_pb2
from . import trace_context_pb2 as _trace_context_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TopologyTransaction(_message.Message):
    __slots__ = ("update_id", "offset", "synchronizer_id", "record_time", "events", "trace_context")
    UPDATE_ID_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    RECORD_TIME_FIELD_NUMBER: _ClassVar[int]
    EVENTS_FIELD_NUMBER: _ClassVar[int]
    TRACE_CONTEXT_FIELD_NUMBER: _ClassVar[int]
    update_id: str
    offset: int
    synchronizer_id: str
    record_time: _timestamp_pb2.Timestamp
    events: _containers.RepeatedCompositeFieldContainer[TopologyEvent]
    trace_context: _trace_context_pb2.TraceContext
    def __init__(self, update_id: _Optional[str] = ..., offset: _Optional[int] = ..., synchronizer_id: _Optional[str] = ..., record_time: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., events: _Optional[_Iterable[_Union[TopologyEvent, _Mapping]]] = ..., trace_context: _Optional[_Union[_trace_context_pb2.TraceContext, _Mapping]] = ...) -> None: ...

class TopologyEvent(_message.Message):
    __slots__ = ("participant_authorization_changed", "participant_authorization_revoked", "participant_authorization_added")
    PARTICIPANT_AUTHORIZATION_CHANGED_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_AUTHORIZATION_REVOKED_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_AUTHORIZATION_ADDED_FIELD_NUMBER: _ClassVar[int]
    participant_authorization_changed: ParticipantAuthorizationChanged
    participant_authorization_revoked: ParticipantAuthorizationRevoked
    participant_authorization_added: ParticipantAuthorizationAdded
    def __init__(self, participant_authorization_changed: _Optional[_Union[ParticipantAuthorizationChanged, _Mapping]] = ..., participant_authorization_revoked: _Optional[_Union[ParticipantAuthorizationRevoked, _Mapping]] = ..., participant_authorization_added: _Optional[_Union[ParticipantAuthorizationAdded, _Mapping]] = ...) -> None: ...

class ParticipantAuthorizationAdded(_message.Message):
    __slots__ = ("party_id", "participant_id", "participant_permission")
    PARTY_ID_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_ID_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_PERMISSION_FIELD_NUMBER: _ClassVar[int]
    party_id: str
    participant_id: str
    participant_permission: _state_service_pb2.ParticipantPermission
    def __init__(self, party_id: _Optional[str] = ..., participant_id: _Optional[str] = ..., participant_permission: _Optional[_Union[_state_service_pb2.ParticipantPermission, str]] = ...) -> None: ...

class ParticipantAuthorizationChanged(_message.Message):
    __slots__ = ("party_id", "participant_id", "participant_permission")
    PARTY_ID_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_ID_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_PERMISSION_FIELD_NUMBER: _ClassVar[int]
    party_id: str
    participant_id: str
    participant_permission: _state_service_pb2.ParticipantPermission
    def __init__(self, party_id: _Optional[str] = ..., participant_id: _Optional[str] = ..., participant_permission: _Optional[_Union[_state_service_pb2.ParticipantPermission, str]] = ...) -> None: ...

class ParticipantAuthorizationRevoked(_message.Message):
    __slots__ = ("party_id", "participant_id")
    PARTY_ID_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_ID_FIELD_NUMBER: _ClassVar[int]
    party_id: str
    participant_id: str
    def __init__(self, party_id: _Optional[str] = ..., participant_id: _Optional[str] = ...) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0

from __future__ import annotations

from abc import ABC, abstractmethod
from typing import Any, Optional, Sequence

from .. import daml_lf_1 as lf

__all__ = ["ProtobufParserBase"]


class ProtobufParserBase(ABC):
    """
    Abstract base class for all DAML-LF protobuf parsers.

    Defines the interface that version-specific parsers must implement.
    Each parser converts version-specific protobuf messages to the common AST (daml_lf_1).
    """

    def __init__(self, current_package: lf.PackageRef) -> None:
        self.current_package = current_package
        self.current_module: Optional[lf.ModuleRef] = None
        self.interned_strings: list[str] = []
        self.interned_dotted_names: list[Sequence[str]] = []
        self.interned_types: list[lf.Type] = []

    @abstractmethod
    def parse_Package(self, pb: Any) -> lf.Package:
        """Parse a Package protobuf message."""
        ...

    # Helper methods that may be common across versions
    def _resolve_string(self, direct: str, interned: int) -> str:
        """Resolve a string that may be direct or interned."""
        if direct:
            return direct
        return self.interned_strings[interned]

    def _resolve_string_seq(self, direct: Sequence[str], interned: Optional[int]) -> Sequence[str]:
        """Resolve a sequence of strings that may be direct or interned."""
        if direct:
            return tuple(direct)
        if interned is not None:
            return self.interned_dotted_names[interned]
        return ()

    def _resolve_dotted_name(self, direct: Any, interned: int) -> lf.DottedName:
        """Resolve a DottedName that may be direct or interned."""
        if direct and hasattr(direct, "segments"):
            return lf.DottedName(segments=direct.segments)
        return lf.DottedName(segments=self.interned_dotted_names[interned])



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/mediator/admin/v30/mediator_inspection_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/mediator/admin/v30/mediator_inspection_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nLcom/digitalasset/canton/mediator/admin/v30/mediator_inspection_service.proto\x12*com.digitalasset.canton.mediator.admin.v30\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa5\x01\n\x0fVerdictsRequest\x12k\n\"most_recently_received_record_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00R\x1emostRecentlyReceivedRecordTime\x88\x01\x01\x42%\n#_most_recently_received_record_time\"a\n\x10VerdictsResponse\x12M\n\x07verdict\x18\x01 \x01(\x0b\x32\x33.com.digitalasset.canton.mediator.admin.v30.VerdictR\x07verdict\"\x8b\x04\n\x07Verdict\x12-\n\x12submitting_parties\x18\x01 \x03(\tR\x11submittingParties\x12<\n\x1asubmitting_participant_uid\x18\x02 \x01(\tR\x18submittingParticipantUid\x12S\n\x07verdict\x18\x03 \x01(\x0e\x32\x39.com.digitalasset.canton.mediator.admin.v30.VerdictResultR\x07verdict\x12G\n\x11\x66inalization_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x10\x66inalizationTime\x12;\n\x0brecord_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nrecordTime\x12%\n\x0emediator_group\x18\x06 \x01(\rR\rmediatorGroup\x12k\n\x11transaction_views\x18\x07 \x01(\x0b\x32<.com.digitalasset.canton.mediator.admin.v30.TransactionViewsH\x00R\x10transactionViews\x12\x1b\n\tupdate_id\x18\x08 \x01(\tR\x08updateIdB\x07\n\x05views\"\x87\x02\n\x10TransactionViews\x12]\n\x05views\x18\x01 \x03(\x0b\x32G.com.digitalasset.canton.mediator.admin.v30.TransactionViews.ViewsEntryR\x05views\x12\x1d\n\nroot_views\x18\x02 \x03(\x05R\trootViews\x1au\n\nViewsEntry\x12\x10\n\x03key\x18\x01 \x01(\x05R\x03key\x12Q\n\x05value\x18\x02 \x01(\x0b\x32;.com.digitalasset.canton.mediator.admin.v30.TransactionViewR\x05value:\x02\x38\x01\"\xaf\x01\n\x0fTransactionView\x12\x1c\n\tinformees\x18\x01 \x03(\tR\tinformees\x12\x61\n\x12\x63onfirming_parties\x18\x02 \x03(\x0b\x32\x32.com.digitalasset.canton.mediator.admin.v30.QuorumR\x11\x63onfirmingParties\x12\x1b\n\tsub_views\x18\x03 \x03(\x05R\x08subViews\"@\n\x06Quorum\x12\x18\n\x07parties\x18\x01 \x03(\tR\x07parties\x12\x1c\n\tthreshold\x18\x02 \x01(\x05R\tthreshold*i\n\rVerdictResult\x12\x1e\n\x1aVERDICT_RESULT_UNSPECIFIED\x10\x00\x12\x1b\n\x17VERDICT_RESULT_ACCEPTED\x10\x01\x12\x1b\n\x17VERDICT_RESULT_REJECTED\x10\x02\x32\xa5\x01\n\x19MediatorInspectionService\x12\x87\x01\n\x08Verdicts\x12;.com.digitalasset.canton.mediator.admin.v30.VerdictsRequest\x1a<.com.digitalasset.canton.mediator.admin.v30.VerdictsResponse0\x01\x42[ZYgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/mediator/admin/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.mediator.admin.v30.mediator_inspection_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZYgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/mediator/admin/v30'
  _globals['_TRANSACTIONVIEWS_VIEWSENTRY']._loaded_options = None
  _globals['_TRANSACTIONVIEWS_VIEWSENTRY']._serialized_options = b'8\001'
  _globals['_VERDICTRESULT']._serialized_start=1460
  _globals['_VERDICTRESULT']._serialized_end=1565
  _globals['_VERDICTSREQUEST']._serialized_start=158
  _globals['_VERDICTSREQUEST']._serialized_end=323
  _globals['_VERDICTSRESPONSE']._serialized_start=325
  _globals['_VERDICTSRESPONSE']._serialized_end=422
  _globals['_VERDICT']._serialized_start=425
  _globals['_VERDICT']._serialized_end=948
  _globals['_TRANSACTIONVIEWS']._serialized_start=951
  _globals['_TRANSACTIONVIEWS']._serialized_end=1214
  _globals['_TRANSACTIONVIEWS_VIEWSENTRY']._serialized_start=1097
  _globals['_TRANSACTIONVIEWS_VIEWSENTRY']._serialized_end=1214
  _globals['_TRANSACTIONVIEW']._serialized_start=1217
  _globals['_TRANSACTIONVIEW']._serialized_end=1392
  _globals['_QUORUM']._serialized_start=1394
  _globals['_QUORUM']._serialized_end=1458
  _globals['_MEDIATORINSPECTIONSERVICE']._serialized_start=1568
  _globals['_MEDIATORINSPECTIONSERVICE']._serialized_end=1733
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/time/v30/time_tracker_config.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/admin/time/v30/time_tracker_config.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@com/digitalasset/canton/admin/time/v30/time_tracker_config.proto\x12&com.digitalasset.canton.admin.time.v30\x1a\x1egoogle/protobuf/duration.proto\"\xf3\x01\n\x16TimeProofRequestConfig\x12I\n\x13initial_retry_delay\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationR\x11initialRetryDelay\x12\x41\n\x0fmax_retry_delay\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\rmaxRetryDelay\x12K\n\x14max_sequencing_delay\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\x12maxSequencingDelay\"\xf6\x02\n\x1dSynchronizerTimeTrackerConfig\x12J\n\x13observation_latency\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationR\x12observationLatency\x12\x46\n\x11patience_duration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x10patienceDuration\x12S\n\x18min_observation_duration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\x16minObservationDuration\x12l\n\x12time_proof_request\x18\x04 \x01(\x0b\x32>.com.digitalasset.canton.admin.time.v30.TimeProofRequestConfigR\x10timeProofRequestBWZUgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/time/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.time.v30.time_tracker_config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZUgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/time/v30'
  _globals['_TIMEPROOFREQUESTCONFIG']._serialized_start=141
  _globals['_TIMEPROOFREQUESTCONFIG']._serialized_end=384
  _globals['_SYNCHRONIZERTIMETRACKERCONFIG']._serialized_start=387
  _globals['_SYNCHRONIZERTIMETRACKERCONFIG']._serialized_end=761
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="ArchivedEvent")


@_attrs_define
class ArchivedEvent:
    """Records that a contract has been archived, and choices may no longer be exercised on it.

    Attributes:
        offset (int): The offset of origin.
            Offsets are managed by the participant nodes.
            Transactions can thus NOT be assumed to have the same offsets on different participant nodes.
            Required, it is a valid absolute offset (positive integer)
        node_id (int): The position of this event in the originating transaction or reassignment.
            Node IDs are not necessarily equal across participants,
            as these may see different projections/parts of transactions.
            Required, must be valid node ID (non-negative integer)
        contract_id (str): The ID of the archived contract.
            Must be a valid LedgerString (as described in ``value.proto``).
            Required
        template_id (str): Identifies the template that defines the choice that archived the contract.
            This template's package-id may differ from the target contract's package-id
            if the target contract has been upgraded or downgraded.

            The identifier uses the package-id reference format.

            Required
        package_name (str): The package name of the contract.
            Required
        witness_parties (list[str] | Unset): The parties that are notified of this event. For an ``ArchivedEvent``,
            these are the intersection of the stakeholders of the contract in
            question and the parties specified in the ``TransactionFilter``. The
            stakeholders are the union of the signatories and the observers of
            the contract.
            Each one of its elements must be a valid PartyIdString (as described
            in ``value.proto``).
            Required
        implemented_interfaces (list[str] | Unset): The interfaces implemented by the target template that have been
            matched from the interface filter query.
            Populated only in case interface filters with include_interface_view set.

            If defined, the identifier uses the package-id reference format.

            Optional
    """

    offset: int
    node_id: int
    contract_id: str
    template_id: str
    package_name: str
    witness_parties: list[str] | Unset = UNSET
    implemented_interfaces: list[str] | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        offset = self.offset

        node_id = self.node_id

        contract_id = self.contract_id

        template_id = self.template_id

        package_name = self.package_name

        witness_parties: list[str] | Unset = UNSET
        if not isinstance(self.witness_parties, Unset):
            witness_parties = self.witness_parties

        implemented_interfaces: list[str] | Unset = UNSET
        if not isinstance(self.implemented_interfaces, Unset):
            implemented_interfaces = self.implemented_interfaces

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "offset": offset,
                "nodeId": node_id,
                "contractId": contract_id,
                "templateId": template_id,
                "packageName": package_name,
            }
        )
        if witness_parties is not UNSET:
            field_dict["witnessParties"] = witness_parties
        if implemented_interfaces is not UNSET:
            field_dict["implementedInterfaces"] = implemented_interfaces

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        offset = d.pop("offset")

        node_id = d.pop("nodeId")

        contract_id = d.pop("contractId")

        template_id = d.pop("templateId")

        package_name = d.pop("packageName")

        witness_parties = cast(list[str], d.pop("witnessParties", UNSET))

        implemented_interfaces = cast(list[str], d.pop("implementedInterfaces", UNSET))

        archived_event = cls(
            offset=offset,
            node_id=node_id,
            contract_id=contract_id,
            template_id=template_id,
            package_name=package_name,
            witness_parties=witness_parties,
            implemented_interfaces=implemented_interfaces,
        )

        archived_event.additional_properties = d
        return archived_event

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/sequencer/admin/v30/sequencer_bft_administration_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/sequencer/admin/v30/sequencer_bft_administration_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nVcom/digitalasset/canton/sequencer/admin/v30/sequencer_bft_administration_service.proto\x12+com.digitalasset.canton.sequencer.admin.v30\"o\n\x16\x41\x64\x64PeerEndpointRequest\x12U\n\x08\x65ndpoint\x18\x01 \x01(\x0b\x32\x39.com.digitalasset.canton.sequencer.admin.v30.PeerEndpointR\x08\x65ndpoint\"y\n\x19RemovePeerEndpointRequest\x12\\\n\x0b\x65ndpoint_id\x18\x01 \x01(\x0b\x32;.com.digitalasset.canton.sequencer.admin.v30.PeerEndpointIdR\nendpointId\"\xff\x01\n\x0cPeerEndpoint\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\x12\x12\n\x04port\x18\x02 \x01(\rR\x04port\x12\x63\n\nplain_text\x18\x03 \x01(\x0b\x32\x42.com.digitalasset.canton.sequencer.admin.v30.PlainTextPeerEndpointH\x00R\tplainText\x12P\n\x03tls\x18\x04 \x01(\x0b\x32<.com.digitalasset.canton.sequencer.admin.v30.TlsPeerEndpointH\x00R\x03tlsB\n\n\x08security\"P\n\x0ePeerEndpointId\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\x12\x12\n\x04port\x18\x02 \x01(\rR\x04port\x12\x10\n\x03tls\x18\x03 \x01(\x08R\x03tls\"\x17\n\x15PlainTextPeerEndpoint\"\xf3\x01\n\x0fTlsPeerEndpoint\x12J\n\x1f\x63ustom_server_trust_certificate\x18\x01 \x01(\x0cH\x00R\x1c\x63ustomServerTrustCertificate\x88\x01\x01\x12p\n\x12\x63lient_certificate\x18\x02 \x01(\x0b\x32\x41.com.digitalasset.canton.sequencer.admin.v30.TlsClientCertificateR\x11\x63lientCertificateB\"\n _custom_server_trust_certificate\"m\n\x14TlsClientCertificate\x12+\n\x11\x63\x65rtificate_chain\x18\x01 \x01(\x0cR\x10\x63\x65rtificateChain\x12(\n\x10private_key_file\x18\x02 \x01(\tR\x0eprivateKeyFile\"/\n\x17\x41\x64\x64PeerEndpointResponse\x12\x14\n\x05\x61\x64\x64\x65\x64\x18\x01 \x01(\x08R\x05\x61\x64\x64\x65\x64\"6\n\x1aRemovePeerEndpointResponse\x12\x18\n\x07removed\x18\x01 \x01(\x08R\x07removed\"2\n\rAuthenticated\x12!\n\x0csequencer_id\x18\x01 \x01(\tR\x0bsequencerId\"\xc1\x04\n\x18PeerEndpointHealthStatus\x12\x82\x01\n\x10unknown_endpoint\x18\x01 \x01(\x0b\x32U.com.digitalasset.canton.sequencer.admin.v30.PeerEndpointHealthStatus.UnknownEndpointH\x00R\x0funknownEndpoint\x12x\n\x0c\x64isconnected\x18\x02 \x01(\x0b\x32R.com.digitalasset.canton.sequencer.admin.v30.PeerEndpointHealthStatus.DisconnectedH\x00R\x0c\x64isconnected\x12\x81\x01\n\x0funauthenticated\x18\x03 \x01(\x0b\x32U.com.digitalasset.canton.sequencer.admin.v30.PeerEndpointHealthStatus.UnauthenticatedH\x00R\x0funauthenticated\x12\x62\n\rauthenticated\x18\x04 \x01(\x0b\x32:.com.digitalasset.canton.sequencer.admin.v30.AuthenticatedH\x00R\rauthenticated\x1a\x11\n\x0fUnknownEndpoint\x1a\x0e\n\x0c\x44isconnected\x1a\x11\n\x0fUnauthenticatedB\x08\n\x06status\"\xaa\x01\n\x12PeerEndpointHealth\x12]\n\x06status\x18\x01 \x01(\x0b\x32\x45.com.digitalasset.canton.sequencer.admin.v30.PeerEndpointHealthStatusR\x06status\x12%\n\x0b\x64\x65scription\x18\x02 \x01(\tH\x00R\x0b\x64\x65scription\x88\x01\x01\x42\x0e\n\x0c_description\"\x81\x02\n\x12PeerEndpointStatus\x12\\\n\x0b\x65ndpoint_id\x18\x01 \x01(\x0b\x32;.com.digitalasset.canton.sequencer.admin.v30.PeerEndpointIdR\nendpointId\x12\x34\n\x16is_outgoing_connection\x18\x02 \x01(\x08R\x14isOutgoingConnection\x12W\n\x06health\x18\x03 \x01(\x0b\x32?.com.digitalasset.canton.sequencer.admin.v30.PeerEndpointHealthR\x06health\"\x8d\x02\n\x14PeerConnectionStatus\x12s\n\x14peer_endpoint_status\x18\x01 \x01(\x0b\x32?.com.digitalasset.canton.sequencer.admin.v30.PeerEndpointStatusH\x00R\x12peerEndpointStatus\x12v\n\x18peer_incoming_connection\x18\x02 \x01(\x0b\x32:.com.digitalasset.canton.sequencer.admin.v30.AuthenticatedH\x00R\x16peerIncomingConnectionB\x08\n\x06status\"}\n\x1bGetPeerNetworkStatusRequest\x12^\n\x0c\x65ndpoint_ids\x18\x01 \x03(\x0b\x32;.com.digitalasset.canton.sequencer.admin.v30.PeerEndpointIdR\x0b\x65ndpointIds\"}\n\x1cGetPeerNetworkStatusResponse\x12]\n\x08statuses\x18\x01 \x03(\x0b\x32\x41.com.digitalasset.canton.sequencer.admin.v30.PeerConnectionStatusR\x08statuses\"\x1c\n\x1aGetOrderingTopologyRequest\"g\n\x1bGetOrderingTopologyResponse\x12#\n\rcurrent_epoch\x18\x01 \x01(\x03R\x0c\x63urrentEpoch\x12#\n\rsequencer_ids\x18\x02 \x03(\tR\x0csequencerIds\"?\n#SetPerformanceMetricsEnabledRequest\x12\x18\n\x07\x65nabled\x18\x01 \x01(\x08R\x07\x65nabled\"&\n$SetPerformanceMetricsEnabledResponse2\x89\x07\n!SequencerBftAdministrationService\x12\x9c\x01\n\x0f\x41\x64\x64PeerEndpoint\x12\x43.com.digitalasset.canton.sequencer.admin.v30.AddPeerEndpointRequest\x1a\x44.com.digitalasset.canton.sequencer.admin.v30.AddPeerEndpointResponse\x12\xa5\x01\n\x12RemovePeerEndpoint\x12\x46.com.digitalasset.canton.sequencer.admin.v30.RemovePeerEndpointRequest\x1aG.com.digitalasset.canton.sequencer.admin.v30.RemovePeerEndpointResponse\x12\xab\x01\n\x14GetPeerNetworkStatus\x12H.com.digitalasset.canton.sequencer.admin.v30.GetPeerNetworkStatusRequest\x1aI.com.digitalasset.canton.sequencer.admin.v30.GetPeerNetworkStatusResponse\x12\xa8\x01\n\x13GetOrderingTopology\x12G.com.digitalasset.canton.sequencer.admin.v30.GetOrderingTopologyRequest\x1aH.com.digitalasset.canton.sequencer.admin.v30.GetOrderingTopologyResponse\x12\xc3\x01\n\x1cSetPerformanceMetricsEnabled\x12P.com.digitalasset.canton.sequencer.admin.v30.SetPerformanceMetricsEnabledRequest\x1aQ.com.digitalasset.canton.sequencer.admin.v30.SetPerformanceMetricsEnabledResponseB\\ZZgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/sequencer/admin/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.sequencer.admin.v30.sequencer_bft_administration_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZZgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/sequencer/admin/v30'
  _globals['_ADDPEERENDPOINTREQUEST']._serialized_start=135
  _globals['_ADDPEERENDPOINTREQUEST']._serialized_end=246
  _globals['_REMOVEPEERENDPOINTREQUEST']._serialized_start=248
  _globals['_REMOVEPEERENDPOINTREQUEST']._serialized_end=369
  _globals['_PEERENDPOINT']._serialized_start=372
  _globals['_PEERENDPOINT']._serialized_end=627
  _globals['_PEERENDPOINTID']._serialized_start=629
  _globals['_PEERENDPOINTID']._serialized_end=709
  _globals['_PLAINTEXTPEERENDPOINT']._serialized_start=711
  _globals['_PLAINTEXTPEERENDPOINT']._serialized_end=734
  _globals['_TLSPEERENDPOINT']._serialized_start=737
  _globals['_TLSPEERENDPOINT']._serialized_end=980
  _globals['_TLSCLIENTCERTIFICATE']._serialized_start=982
  _globals['_TLSCLIENTCERTIFICATE']._serialized_end=1091
  _globals['_ADDPEERENDPOINTRESPONSE']._serialized_start=1093
  _globals['_ADDPEERENDPOINTRESPONSE']._serialized_end=1140
  _globals['_REMOVEPEERENDPOINTRESPONSE']._serialized_start=1142
  _globals['_REMOVEPEERENDPOINTRESPONSE']._serialized_end=1196
  _globals['_AUTHENTICATED']._serialized_start=1198
  _globals['_AUTHENTICATED']._serialized_end=1248
  _globals['_PEERENDPOINTHEALTHSTATUS']._serialized_start=1251
  _globals['_PEERENDPOINTHEALTHSTATUS']._serialized_end=1828
  _globals['_PEERENDPOINTHEALTHSTATUS_UNKNOWNENDPOINT']._serialized_start=1766
  _globals['_PEERENDPOINTHEALTHSTATUS_UNKNOWNENDPOINT']._serialized_end=1783
  _globals['_PEERENDPOINTHEALTHSTATUS_DISCONNECTED']._serialized_start=1785
  _globals['_PEERENDPOINTHEALTHSTATUS_DISCONNECTED']._serialized_end=1799
  _globals['_PEERENDPOINTHEALTHSTATUS_UNAUTHENTICATED']._serialized_start=1801
  _globals['_PEERENDPOINTHEALTHSTATUS_UNAUTHENTICATED']._serialized_end=1818
  _globals['_PEERENDPOINTHEALTH']._serialized_start=1831
  _globals['_PEERENDPOINTHEALTH']._serialized_end=2001
  _globals['_PEERENDPOINTSTATUS']._serialized_start=2004
  _globals['_PEERENDPOINTSTATUS']._serialized_end=2261
  _globals['_PEERCONNECTIONSTATUS']._serialized_start=2264
  _globals['_PEERCONNECTIONSTATUS']._serialized_end=2533
  _globals['_GETPEERNETWORKSTATUSREQUEST']._serialized_start=2535
  _globals['_GETPEERNETWORKSTATUSREQUEST']._serialized_end=2660
  _globals['_GETPEERNETWORKSTATUSRESPONSE']._serialized_start=2662
  _globals['_GETPEERNETWORKSTATUSRESPONSE']._serialized_end=2787
  _globals['_GETORDERINGTOPOLOGYREQUEST']._serialized_start=2789
  _globals['_GETORDERINGTOPOLOGYREQUEST']._serialized_end=2817
  _globals['_GETORDERINGTOPOLOGYRESPONSE']._serialized_start=2819
  _globals['_GETORDERINGTOPOLOGYRESPONSE']._serialized_end=2922
  _globals['_SETPERFORMANCEMETRICSENABLEDREQUEST']._serialized_start=2924
  _globals['_SETPERFORMANCEMETRICSENABLEDREQUEST']._serialized_end=2987
  _globals['_SETPERFORMANCEMETRICSENABLEDRESPONSE']._serialized_start=2989
  _globals['_SETPERFORMANCEMETRICSENABLEDRESPONSE']._serialized_end=3027
  _globals['_SEQUENCERBFTADMINISTRATIONSERVICE']._serialized_start=3030
  _globals['_SEQUENCERBFTADMINISTRATIONSERVICE']._serialized_end=3935
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import party_management_service_pb2 as com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_party__management__service__pb2

GRPC_GENERATED_VERSION = '1.76.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + ' but the generated code in com/digitalasset/canton/admin/participant/v30/party_management_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class PartyManagementServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.AddPartyAsync = channel.unary_unary(
                '/com.digitalasset.canton.admin.participant.v30.PartyManagementService/AddPartyAsync',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_party__management__service__pb2.AddPartyAsyncRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_party__management__service__pb2.AddPartyAsyncResponse.FromString,
                _registered_method=True)
        self.GetAddPartyStatus = channel.unary_unary(
                '/com.digitalasset.canton.admin.participant.v30.PartyManagementService/GetAddPartyStatus',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_party__management__service__pb2.GetAddPartyStatusRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_party__management__service__pb2.GetAddPartyStatusResponse.FromString,
                _registered_method=True)
        self.ExportPartyAcs = channel.unary_stream(
                '/com.digitalasset.canton.admin.participant.v30.PartyManagementService/ExportPartyAcs',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_party__management__service__pb2.ExportPartyAcsRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_party__management__service__pb2.ExportPartyAcsResponse.FromString,
                _registered_method=True)
        self.ImportPartyAcs = channel.stream_unary(
                '/com.digitalasset.canton.admin.participant.v30.PartyManagementService/ImportPartyAcs',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_party__management__service__pb2.ImportPartyAcsRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_party__management__service__pb2.ImportPartyAcsResponse.FromString,
                _registered_method=True)
        self.GetHighestOffsetByTimestamp = channel.unary_unary(
                '/com.digitalasset.canton.admin.participant.v30.PartyManagementService/GetHighestOffsetByTimestamp',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_party__management__service__pb2.GetHighestOffsetByTimestampRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_party__management__service__pb2.GetHighestOffsetByTimestampResponse.FromString,
                _registered_method=True)
        self.ClearPartyOnboardingFlag = channel.unary_unary(
                '/com.digitalasset.canton.admin.participant.v30.PartyManagementService/ClearPartyOnboardingFlag',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_party__management__service__pb2.ClearPartyOnboardingFlagRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_party__management__service__pb2.ClearPartyOnboardingFlagResponse.FromString,
                _registered_method=True)


class PartyManagementServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def AddPartyAsync(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAddPartyStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExportPartyAcs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ImportPartyAcs(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetHighestOffsetByTimestamp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ClearPartyOnboardingFlag(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PartyManagementServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'AddPartyAsync': grpc.unary_unary_rpc_method_handler(
                    servicer.AddPartyAsync,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_party__management__service__pb2.AddPartyAsyncRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_party__management__service__pb2.AddPartyAsyncResponse.SerializeToString,
            ),
            'GetAddPartyStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAddPartyStatus,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_party__management__service__pb2.GetAddPartyStatusRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_party__management__service__pb2.GetAddPartyStatusResponse.SerializeToString,
            ),
            'ExportPartyAcs': grpc.unary_stream_rpc_method_handler(
                    servicer.ExportPartyAcs,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_party__management__service__pb2.ExportPartyAcsRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_party__management__service__pb2.ExportPartyAcsResponse.SerializeToString,
            ),
            'ImportPartyAcs': grpc.stream_unary_rpc_method_handler(
                    servicer.ImportPartyAcs,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_party__management__service__pb2.ImportPartyAcsRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_party__management__service__pb2.ImportPartyAcsResponse.SerializeToString,
            ),
            'GetHighestOffsetByTimestamp': grpc.unary_unary_rpc_method_handler(
                    servicer.GetHighestOffsetByTimestamp,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_party__management__service__pb2.GetHighestOffsetByTimestampRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_party__management__service__pb2.GetHighestOffsetByTimestampResponse.SerializeToString,
            ),
            'ClearPartyOnboardingFlag': grpc.unary_unary_rpc_method_handler(
                    servicer.ClearPartyOnboardingFlag,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_party__management__service__pb2.ClearPartyOnboardingFlagRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_party__management__service__pb2.ClearPartyOnboardingFlagResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'com.digitalasset.canton.admin.participant.v30.PartyManagementService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('com.digitalasset.canton.admin.participant.v30.PartyManagementService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class PartyManagementService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def AddPartyAsync(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.PartyManagementService/AddPartyAsync',
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_party__management__service__pb2.AddPartyAsyncRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_party__management__service__pb2.AddPartyAsyncResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetAddPartyStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.PartyManagementService/GetAddPartyStatus',
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_party__management__service__pb2.GetAddPartyStatusRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_party__management__service__pb2.GetAddPartyStatusResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ExportPartyAcs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.PartyManagementService/ExportPartyAcs',
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_party__management__service__pb2.ExportPartyAcsRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_party__management__service__pb2.ExportPartyAcsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ImportPartyAcs(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(
            request_iterator,
            target,
            '/com.digitalasset.canton.admin.participant.v30.PartyManagementService/ImportPartyAcs',
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_party__management__service__pb2.ImportPartyAcsRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_party__management__service__pb2.ImportPartyAcsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetHighestOffsetByTimestamp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.PartyManagementService/GetHighestOffsetByTimestamp',
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_party__management__service__pb2.GetHighestOffsetByTimestampRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_party__management__service__pb2.GetHighestOffsetByTimestampResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ClearPartyOnboardingFlag(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.PartyManagementService/ClearPartyOnboardingFlag',
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_party__management__service__pb2.ClearPartyOnboardingFlagRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_party__management__service__pb2.ClearPartyOnboardingFlagResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="TopologyStateFilter")


@_attrs_define
class TopologyStateFilter:
    """Filter the vetted packages by the participant and synchronizer that they are
    hosted on.

    Empty fields are ignored, such that a ``TopologyStateFilter`` without
    participant_ids and without synchronizer_ids matches a vetted package hosted
    on any participant and synchronizer.

    Non-empty fields specify candidate values of which at least one must match.
    If both fields are set then at least one candidate value must match from each
    field.

        Attributes:
            participant_ids (list[str] | Unset): If this list is non-empty, only vetted packages hosted on participants
                listed in this field match the filter.
                Query the current Ledger API's participant's ID via the public
                ``GetParticipantId`` command in ``PartyManagementService``.
            synchronizer_ids (list[str] | Unset): If this list is non-empty, only vetted packages from the topology state of
                the synchronizers in this list match the filter.
    """

    participant_ids: list[str] | Unset = UNSET
    synchronizer_ids: list[str] | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        participant_ids: list[str] | Unset = UNSET
        if not isinstance(self.participant_ids, Unset):
            participant_ids = self.participant_ids

        synchronizer_ids: list[str] | Unset = UNSET
        if not isinstance(self.synchronizer_ids, Unset):
            synchronizer_ids = self.synchronizer_ids

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if participant_ids is not UNSET:
            field_dict["participantIds"] = participant_ids
        if synchronizer_ids is not UNSET:
            field_dict["synchronizerIds"] = synchronizer_ids

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        participant_ids = cast(list[str], d.pop("participantIds", UNSET))

        synchronizer_ids = cast(list[str], d.pop("synchronizerIds", UNSET))

        topology_state_filter = cls(
            participant_ids=participant_ids,
            synchronizer_ids=synchronizer_ids,
        )

        topology_state_filter.additional_properties = d
        return topology_state_filter

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
import datetime

from .. import commands_pb2 as _commands_pb2
from .. import crypto_pb2 as _crypto_pb2
from . import interactive_submission_common_data_pb2 as _interactive_submission_common_data_pb2
from .transaction.v1 import interactive_submission_data_pb2 as _interactive_submission_data_pb2
from .. import package_reference_pb2 as _package_reference_pb2
from .. import transaction_pb2 as _transaction_pb2
from .. import transaction_filter_pb2 as _transaction_filter_pb2
from .. import value_pb2 as _value_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class HashingSchemeVersion(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    HASHING_SCHEME_VERSION_UNSPECIFIED: _ClassVar[HashingSchemeVersion]
    HASHING_SCHEME_VERSION_V2: _ClassVar[HashingSchemeVersion]
HASHING_SCHEME_VERSION_UNSPECIFIED: HashingSchemeVersion
HASHING_SCHEME_VERSION_V2: HashingSchemeVersion

class CostEstimationHints(_message.Message):
    __slots__ = ("disabled", "expected_signatures")
    DISABLED_FIELD_NUMBER: _ClassVar[int]
    EXPECTED_SIGNATURES_FIELD_NUMBER: _ClassVar[int]
    disabled: bool
    expected_signatures: _containers.RepeatedScalarFieldContainer[_crypto_pb2.SigningAlgorithmSpec]
    def __init__(self, disabled: bool = ..., expected_signatures: _Optional[_Iterable[_Union[_crypto_pb2.SigningAlgorithmSpec, str]]] = ...) -> None: ...

class CostEstimation(_message.Message):
    __slots__ = ("estimation_timestamp", "confirmation_request_traffic_cost_estimation", "confirmation_response_traffic_cost_estimation", "total_traffic_cost_estimation")
    ESTIMATION_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    CONFIRMATION_REQUEST_TRAFFIC_COST_ESTIMATION_FIELD_NUMBER: _ClassVar[int]
    CONFIRMATION_RESPONSE_TRAFFIC_COST_ESTIMATION_FIELD_NUMBER: _ClassVar[int]
    TOTAL_TRAFFIC_COST_ESTIMATION_FIELD_NUMBER: _ClassVar[int]
    estimation_timestamp: _timestamp_pb2.Timestamp
    confirmation_request_traffic_cost_estimation: int
    confirmation_response_traffic_cost_estimation: int
    total_traffic_cost_estimation: int
    def __init__(self, estimation_timestamp: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., confirmation_request_traffic_cost_estimation: _Optional[int] = ..., confirmation_response_traffic_cost_estimation: _Optional[int] = ..., total_traffic_cost_estimation: _Optional[int] = ...) -> None: ...

class PrepareSubmissionRequest(_message.Message):
    __slots__ = ("user_id", "command_id", "commands", "min_ledger_time", "max_record_time", "act_as", "read_as", "disclosed_contracts", "synchronizer_id", "package_id_selection_preference", "verbose_hashing", "prefetch_contract_keys", "estimate_traffic_cost")
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    COMMAND_ID_FIELD_NUMBER: _ClassVar[int]
    COMMANDS_FIELD_NUMBER: _ClassVar[int]
    MIN_LEDGER_TIME_FIELD_NUMBER: _ClassVar[int]
    MAX_RECORD_TIME_FIELD_NUMBER: _ClassVar[int]
    ACT_AS_FIELD_NUMBER: _ClassVar[int]
    READ_AS_FIELD_NUMBER: _ClassVar[int]
    DISCLOSED_CONTRACTS_FIELD_NUMBER: _ClassVar[int]
    SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    PACKAGE_ID_SELECTION_PREFERENCE_FIELD_NUMBER: _ClassVar[int]
    VERBOSE_HASHING_FIELD_NUMBER: _ClassVar[int]
    PREFETCH_CONTRACT_KEYS_FIELD_NUMBER: _ClassVar[int]
    ESTIMATE_TRAFFIC_COST_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    command_id: str
    commands: _containers.RepeatedCompositeFieldContainer[_commands_pb2.Command]
    min_ledger_time: MinLedgerTime
    max_record_time: _timestamp_pb2.Timestamp
    act_as: _containers.RepeatedScalarFieldContainer[str]
    read_as: _containers.RepeatedScalarFieldContainer[str]
    disclosed_contracts: _containers.RepeatedCompositeFieldContainer[_commands_pb2.DisclosedContract]
    synchronizer_id: str
    package_id_selection_preference: _containers.RepeatedScalarFieldContainer[str]
    verbose_hashing: bool
    prefetch_contract_keys: _containers.RepeatedCompositeFieldContainer[_commands_pb2.PrefetchContractKey]
    estimate_traffic_cost: CostEstimationHints
    def __init__(self, user_id: _Optional[str] = ..., command_id: _Optional[str] = ..., commands: _Optional[_Iterable[_Union[_commands_pb2.Command, _Mapping]]] = ..., min_ledger_time: _Optional[_Union[MinLedgerTime, _Mapping]] = ..., max_record_time: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., act_as: _Optional[_Iterable[str]] = ..., read_as: _Optional[_Iterable[str]] = ..., disclosed_contracts: _Optional[_Iterable[_Union[_commands_pb2.DisclosedContract, _Mapping]]] = ..., synchronizer_id: _Optional[str] = ..., package_id_selection_preference: _Optional[_Iterable[str]] = ..., verbose_hashing: bool = ..., prefetch_contract_keys: _Optional[_Iterable[_Union[_commands_pb2.PrefetchContractKey, _Mapping]]] = ..., estimate_traffic_cost: _Optional[_Union[CostEstimationHints, _Mapping]] = ...) -> None: ...

class PrepareSubmissionResponse(_message.Message):
    __slots__ = ("prepared_transaction", "prepared_transaction_hash", "hashing_scheme_version", "hashing_details", "cost_estimation")
    PREPARED_TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    PREPARED_TRANSACTION_HASH_FIELD_NUMBER: _ClassVar[int]
    HASHING_SCHEME_VERSION_FIELD_NUMBER: _ClassVar[int]
    HASHING_DETAILS_FIELD_NUMBER: _ClassVar[int]
    COST_ESTIMATION_FIELD_NUMBER: _ClassVar[int]
    prepared_transaction: PreparedTransaction
    prepared_transaction_hash: bytes
    hashing_scheme_version: HashingSchemeVersion
    hashing_details: str
    cost_estimation: CostEstimation
    def __init__(self, prepared_transaction: _Optional[_Union[PreparedTransaction, _Mapping]] = ..., prepared_transaction_hash: _Optional[bytes] = ..., hashing_scheme_version: _Optional[_Union[HashingSchemeVersion, str]] = ..., hashing_details: _Optional[str] = ..., cost_estimation: _Optional[_Union[CostEstimation, _Mapping]] = ...) -> None: ...

class SinglePartySignatures(_message.Message):
    __slots__ = ("party", "signatures")
    PARTY_FIELD_NUMBER: _ClassVar[int]
    SIGNATURES_FIELD_NUMBER: _ClassVar[int]
    party: str
    signatures: _containers.RepeatedCompositeFieldContainer[_crypto_pb2.Signature]
    def __init__(self, party: _Optional[str] = ..., signatures: _Optional[_Iterable[_Union[_crypto_pb2.Signature, _Mapping]]] = ...) -> None: ...

class PartySignatures(_message.Message):
    __slots__ = ("signatures",)
    SIGNATURES_FIELD_NUMBER: _ClassVar[int]
    signatures: _containers.RepeatedCompositeFieldContainer[SinglePartySignatures]
    def __init__(self, signatures: _Optional[_Iterable[_Union[SinglePartySignatures, _Mapping]]] = ...) -> None: ...

class ExecuteSubmissionRequest(_message.Message):
    __slots__ = ("prepared_transaction", "party_signatures", "deduplication_duration", "deduplication_offset", "submission_id", "user_id", "hashing_scheme_version", "min_ledger_time")
    PREPARED_TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    PARTY_SIGNATURES_FIELD_NUMBER: _ClassVar[int]
    DEDUPLICATION_DURATION_FIELD_NUMBER: _ClassVar[int]
    DEDUPLICATION_OFFSET_FIELD_NUMBER: _ClassVar[int]
    SUBMISSION_ID_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    HASHING_SCHEME_VERSION_FIELD_NUMBER: _ClassVar[int]
    MIN_LEDGER_TIME_FIELD_NUMBER: _ClassVar[int]
    prepared_transaction: PreparedTransaction
    party_signatures: PartySignatures
    deduplication_duration: _duration_pb2.Duration
    deduplication_offset: int
    submission_id: str
    user_id: str
    hashing_scheme_version: HashingSchemeVersion
    min_ledger_time: MinLedgerTime
    def __init__(self, prepared_transaction: _Optional[_Union[PreparedTransaction, _Mapping]] = ..., party_signatures: _Optional[_Union[PartySignatures, _Mapping]] = ..., deduplication_duration: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ..., deduplication_offset: _Optional[int] = ..., submission_id: _Optional[str] = ..., user_id: _Optional[str] = ..., hashing_scheme_version: _Optional[_Union[HashingSchemeVersion, str]] = ..., min_ledger_time: _Optional[_Union[MinLedgerTime, _Mapping]] = ...) -> None: ...

class ExecuteSubmissionResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ExecuteSubmissionAndWaitRequest(_message.Message):
    __slots__ = ("prepared_transaction", "party_signatures", "deduplication_duration", "deduplication_offset", "submission_id", "user_id", "hashing_scheme_version", "min_ledger_time")
    PREPARED_TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    PARTY_SIGNATURES_FIELD_NUMBER: _ClassVar[int]
    DEDUPLICATION_DURATION_FIELD_NUMBER: _ClassVar[int]
    DEDUPLICATION_OFFSET_FIELD_NUMBER: _ClassVar[int]
    SUBMISSION_ID_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    HASHING_SCHEME_VERSION_FIELD_NUMBER: _ClassVar[int]
    MIN_LEDGER_TIME_FIELD_NUMBER: _ClassVar[int]
    prepared_transaction: PreparedTransaction
    party_signatures: PartySignatures
    deduplication_duration: _duration_pb2.Duration
    deduplication_offset: int
    submission_id: str
    user_id: str
    hashing_scheme_version: HashingSchemeVersion
    min_ledger_time: MinLedgerTime
    def __init__(self, prepared_transaction: _Optional[_Union[PreparedTransaction, _Mapping]] = ..., party_signatures: _Optional[_Union[PartySignatures, _Mapping]] = ..., deduplication_duration: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ..., deduplication_offset: _Optional[int] = ..., submission_id: _Optional[str] = ..., user_id: _Optional[str] = ..., hashing_scheme_version: _Optional[_Union[HashingSchemeVersion, str]] = ..., min_ledger_time: _Optional[_Union[MinLedgerTime, _Mapping]] = ...) -> None: ...

class ExecuteSubmissionAndWaitResponse(_message.Message):
    __slots__ = ("update_id", "completion_offset")
    UPDATE_ID_FIELD_NUMBER: _ClassVar[int]
    COMPLETION_OFFSET_FIELD_NUMBER: _ClassVar[int]
    update_id: str
    completion_offset: int
    def __init__(self, update_id: _Optional[str] = ..., completion_offset: _Optional[int] = ...) -> None: ...

class ExecuteSubmissionAndWaitForTransactionRequest(_message.Message):
    __slots__ = ("prepared_transaction", "party_signatures", "deduplication_duration", "deduplication_offset", "submission_id", "user_id", "hashing_scheme_version", "min_ledger_time", "transaction_format")
    PREPARED_TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    PARTY_SIGNATURES_FIELD_NUMBER: _ClassVar[int]
    DEDUPLICATION_DURATION_FIELD_NUMBER: _ClassVar[int]
    DEDUPLICATION_OFFSET_FIELD_NUMBER: _ClassVar[int]
    SUBMISSION_ID_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    HASHING_SCHEME_VERSION_FIELD_NUMBER: _ClassVar[int]
    MIN_LEDGER_TIME_FIELD_NUMBER: _ClassVar[int]
    TRANSACTION_FORMAT_FIELD_NUMBER: _ClassVar[int]
    prepared_transaction: PreparedTransaction
    party_signatures: PartySignatures
    deduplication_duration: _duration_pb2.Duration
    deduplication_offset: int
    submission_id: str
    user_id: str
    hashing_scheme_version: HashingSchemeVersion
    min_ledger_time: MinLedgerTime
    transaction_format: _transaction_filter_pb2.TransactionFormat
    def __init__(self, prepared_transaction: _Optional[_Union[PreparedTransaction, _Mapping]] = ..., party_signatures: _Optional[_Union[PartySignatures, _Mapping]] = ..., deduplication_duration: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ..., deduplication_offset: _Optional[int] = ..., submission_id: _Optional[str] = ..., user_id: _Optional[str] = ..., hashing_scheme_version: _Optional[_Union[HashingSchemeVersion, str]] = ..., min_ledger_time: _Optional[_Union[MinLedgerTime, _Mapping]] = ..., transaction_format: _Optional[_Union[_transaction_filter_pb2.TransactionFormat, _Mapping]] = ...) -> None: ...

class ExecuteSubmissionAndWaitForTransactionResponse(_message.Message):
    __slots__ = ("transaction",)
    TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    transaction: _transaction_pb2.Transaction
    def __init__(self, transaction: _Optional[_Union[_transaction_pb2.Transaction, _Mapping]] = ...) -> None: ...

class MinLedgerTime(_message.Message):
    __slots__ = ("min_ledger_time_abs", "min_ledger_time_rel")
    MIN_LEDGER_TIME_ABS_FIELD_NUMBER: _ClassVar[int]
    MIN_LEDGER_TIME_REL_FIELD_NUMBER: _ClassVar[int]
    min_ledger_time_abs: _timestamp_pb2.Timestamp
    min_ledger_time_rel: _duration_pb2.Duration
    def __init__(self, min_ledger_time_abs: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., min_ledger_time_rel: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ...) -> None: ...

class PreparedTransaction(_message.Message):
    __slots__ = ("transaction", "metadata")
    TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    transaction: DamlTransaction
    metadata: Metadata
    def __init__(self, transaction: _Optional[_Union[DamlTransaction, _Mapping]] = ..., metadata: _Optional[_Union[Metadata, _Mapping]] = ...) -> None: ...

class Metadata(_message.Message):
    __slots__ = ("submitter_info", "synchronizer_id", "mediator_group", "transaction_uuid", "preparation_time", "input_contracts", "min_ledger_effective_time", "max_ledger_effective_time", "global_key_mapping", "max_record_time")
    class SubmitterInfo(_message.Message):
        __slots__ = ("act_as", "command_id")
        ACT_AS_FIELD_NUMBER: _ClassVar[int]
        COMMAND_ID_FIELD_NUMBER: _ClassVar[int]
        act_as: _containers.RepeatedScalarFieldContainer[str]
        command_id: str
        def __init__(self, act_as: _Optional[_Iterable[str]] = ..., command_id: _Optional[str] = ...) -> None: ...
    class GlobalKeyMappingEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: _interactive_submission_common_data_pb2.GlobalKey
        value: _value_pb2.Value
        def __init__(self, key: _Optional[_Union[_interactive_submission_common_data_pb2.GlobalKey, _Mapping]] = ..., value: _Optional[_Union[_value_pb2.Value, _Mapping]] = ...) -> None: ...
    class InputContract(_message.Message):
        __slots__ = ("v1", "created_at", "event_blob")
        V1_FIELD_NUMBER: _ClassVar[int]
        CREATED_AT_FIELD_NUMBER: _ClassVar[int]
        EVENT_BLOB_FIELD_NUMBER: _ClassVar[int]
        v1: _interactive_submission_data_pb2.Create
        created_at: int
        event_blob: bytes
        def __init__(self, v1: _Optional[_Union[_interactive_submission_data_pb2.Create, _Mapping]] = ..., created_at: _Optional[int] = ..., event_blob: _Optional[bytes] = ...) -> None: ...
    SUBMITTER_INFO_FIELD_NUMBER: _ClassVar[int]
    SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    MEDIATOR_GROUP_FIELD_NUMBER: _ClassVar[int]
    TRANSACTION_UUID_FIELD_NUMBER: _ClassVar[int]
    PREPARATION_TIME_FIELD_NUMBER: _ClassVar[int]
    INPUT_CONTRACTS_FIELD_NUMBER: _ClassVar[int]
    MIN_LEDGER_EFFECTIVE_TIME_FIELD_NUMBER: _ClassVar[int]
    MAX_LEDGER_EFFECTIVE_TIME_FIELD_NUMBER: _ClassVar[int]
    GLOBAL_KEY_MAPPING_FIELD_NUMBER: _ClassVar[int]
    MAX_RECORD_TIME_FIELD_NUMBER: _ClassVar[int]
    submitter_info: Metadata.SubmitterInfo
    synchronizer_id: str
    mediator_group: int
    transaction_uuid: str
    preparation_time: int
    input_contracts: _containers.RepeatedCompositeFieldContainer[Metadata.InputContract]
    min_ledger_effective_time: int
    max_ledger_effective_time: int
    global_key_mapping: _containers.RepeatedCompositeFieldContainer[Metadata.GlobalKeyMappingEntry]
    max_record_time: int
    def __init__(self, submitter_info: _Optional[_Union[Metadata.SubmitterInfo, _Mapping]] = ..., synchronizer_id: _Optional[str] = ..., mediator_group: _Optional[int] = ..., transaction_uuid: _Optional[str] = ..., preparation_time: _Optional[int] = ..., input_contracts: _Optional[_Iterable[_Union[Metadata.InputContract, _Mapping]]] = ..., min_ledger_effective_time: _Optional[int] = ..., max_ledger_effective_time: _Optional[int] = ..., global_key_mapping: _Optional[_Iterable[_Union[Metadata.GlobalKeyMappingEntry, _Mapping]]] = ..., max_record_time: _Optional[int] = ...) -> None: ...

class DamlTransaction(_message.Message):
    __slots__ = ("version", "roots", "nodes", "node_seeds")
    class NodeSeed(_message.Message):
        __slots__ = ("node_id", "seed")
        NODE_ID_FIELD_NUMBER: _ClassVar[int]
        SEED_FIELD_NUMBER: _ClassVar[int]
        node_id: int
        seed: bytes
        def __init__(self, node_id: _Optional[int] = ..., seed: _Optional[bytes] = ...) -> None: ...
    class Node(_message.Message):
        __slots__ = ("node_id", "v1")
        NODE_ID_FIELD_NUMBER: _ClassVar[int]
        V1_FIELD_NUMBER: _ClassVar[int]
        node_id: str
        v1: _interactive_submission_data_pb2.Node
        def __init__(self, node_id: _Optional[str] = ..., v1: _Optional[_Union[_interactive_submission_data_pb2.Node, _Mapping]] = ...) -> None: ...
    VERSION_FIELD_NUMBER: _ClassVar[int]
    ROOTS_FIELD_NUMBER: _ClassVar[int]
    NODES_FIELD_NUMBER: _ClassVar[int]
    NODE_SEEDS_FIELD_NUMBER: _ClassVar[int]
    version: str
    roots: _containers.RepeatedScalarFieldContainer[str]
    nodes: _containers.RepeatedCompositeFieldContainer[DamlTransaction.Node]
    node_seeds: _containers.RepeatedCompositeFieldContainer[DamlTransaction.NodeSeed]
    def __init__(self, version: _Optional[str] = ..., roots: _Optional[_Iterable[str]] = ..., nodes: _Optional[_Iterable[_Union[DamlTransaction.Node, _Mapping]]] = ..., node_seeds: _Optional[_Iterable[_Union[DamlTransaction.NodeSeed, _Mapping]]] = ...) -> None: ...

class GetPreferredPackageVersionRequest(_message.Message):
    __slots__ = ("parties", "package_name", "synchronizer_id", "vetting_valid_at")
    PARTIES_FIELD_NUMBER: _ClassVar[int]
    PACKAGE_NAME_FIELD_NUMBER: _ClassVar[int]
    SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    VETTING_VALID_AT_FIELD_NUMBER: _ClassVar[int]
    parties: _containers.RepeatedScalarFieldContainer[str]
    package_name: str
    synchronizer_id: str
    vetting_valid_at: _timestamp_pb2.Timestamp
    def __init__(self, parties: _Optional[_Iterable[str]] = ..., package_name: _Optional[str] = ..., synchronizer_id: _Optional[str] = ..., vetting_valid_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class GetPreferredPackageVersionResponse(_message.Message):
    __slots__ = ("package_preference",)
    PACKAGE_PREFERENCE_FIELD_NUMBER: _ClassVar[int]
    package_preference: PackagePreference
    def __init__(self, package_preference: _Optional[_Union[PackagePreference, _Mapping]] = ...) -> None: ...

class PackagePreference(_message.Message):
    __slots__ = ("package_reference", "synchronizer_id")
    PACKAGE_REFERENCE_FIELD_NUMBER: _ClassVar[int]
    SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    package_reference: _package_reference_pb2.PackageReference
    synchronizer_id: str
    def __init__(self, package_reference: _Optional[_Union[_package_reference_pb2.PackageReference, _Mapping]] = ..., synchronizer_id: _Optional[str] = ...) -> None: ...

class PackageVettingRequirement(_message.Message):
    __slots__ = ("parties", "package_name")
    PARTIES_FIELD_NUMBER: _ClassVar[int]
    PACKAGE_NAME_FIELD_NUMBER: _ClassVar[int]
    parties: _containers.RepeatedScalarFieldContainer[str]
    package_name: str
    def __init__(self, parties: _Optional[_Iterable[str]] = ..., package_name: _Optional[str] = ...) -> None: ...

class GetPreferredPackagesRequest(_message.Message):
    __slots__ = ("package_vetting_requirements", "synchronizer_id", "vetting_valid_at")
    PACKAGE_VETTING_REQUIREMENTS_FIELD_NUMBER: _ClassVar[int]
    SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    VETTING_VALID_AT_FIELD_NUMBER: _ClassVar[int]
    package_vetting_requirements: _containers.RepeatedCompositeFieldContainer[PackageVettingRequirement]
    synchronizer_id: str
    vetting_valid_at: _timestamp_pb2.Timestamp
    def __init__(self, package_vetting_requirements: _Optional[_Iterable[_Union[PackageVettingRequirement, _Mapping]]] = ..., synchronizer_id: _Optional[str] = ..., vetting_valid_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class GetPreferredPackagesResponse(_message.Message):
    __slots__ = ("package_references", "synchronizer_id")
    PACKAGE_REFERENCES_FIELD_NUMBER: _ClassVar[int]
    SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    package_references: _containers.RepeatedCompositeFieldContainer[_package_reference_pb2.PackageReference]
    synchronizer_id: str
    def __init__(self, package_references: _Optional[_Iterable[_Union[_package_reference_pb2.PackageReference, _Mapping]]] = ..., synchronizer_id: _Optional[str] = ...) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from . import commands_pb2 as _commands_pb2
from . import transaction_pb2 as _transaction_pb2
from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SubmitAndWaitRequest(_message.Message):
    __slots__ = ("commands",)
    COMMANDS_FIELD_NUMBER: _ClassVar[int]
    commands: _commands_pb2.Commands
    def __init__(self, commands: _Optional[_Union[_commands_pb2.Commands, _Mapping]] = ...) -> None: ...

class SubmitAndWaitForTransactionIdResponse(_message.Message):
    __slots__ = ("transaction_id", "completion_offset")
    TRANSACTION_ID_FIELD_NUMBER: _ClassVar[int]
    COMPLETION_OFFSET_FIELD_NUMBER: _ClassVar[int]
    transaction_id: str
    completion_offset: str
    def __init__(self, transaction_id: _Optional[str] = ..., completion_offset: _Optional[str] = ...) -> None: ...

class SubmitAndWaitForTransactionResponse(_message.Message):
    __slots__ = ("transaction", "completion_offset")
    TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    COMPLETION_OFFSET_FIELD_NUMBER: _ClassVar[int]
    transaction: _transaction_pb2.Transaction
    completion_offset: str
    def __init__(self, transaction: _Optional[_Union[_transaction_pb2.Transaction, _Mapping]] = ..., completion_offset: _Optional[str] = ...) -> None: ...

class SubmitAndWaitForTransactionTreeResponse(_message.Message):
    __slots__ = ("transaction", "completion_offset")
    TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    COMPLETION_OFFSET_FIELD_NUMBER: _ClassVar[int]
    transaction: _transaction_pb2.TransactionTree
    completion_offset: str
    def __init__(self, transaction: _Optional[_Union[_transaction_pb2.TransactionTree, _Mapping]] = ..., completion_offset: _Optional[str] = ...) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="Field")


@_attrs_define
class Field:
    """
    Attributes:
        varint (list[int] | Unset):
        fixed64 (list[int] | Unset):
        fixed32 (list[int] | Unset):
        length_delimited (list[str] | Unset):
    """

    varint: list[int] | Unset = UNSET
    fixed64: list[int] | Unset = UNSET
    fixed32: list[int] | Unset = UNSET
    length_delimited: list[str] | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        varint: list[int] | Unset = UNSET
        if not isinstance(self.varint, Unset):
            varint = self.varint

        fixed64: list[int] | Unset = UNSET
        if not isinstance(self.fixed64, Unset):
            fixed64 = self.fixed64

        fixed32: list[int] | Unset = UNSET
        if not isinstance(self.fixed32, Unset):
            fixed32 = self.fixed32

        length_delimited: list[str] | Unset = UNSET
        if not isinstance(self.length_delimited, Unset):
            length_delimited = self.length_delimited

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if varint is not UNSET:
            field_dict["varint"] = varint
        if fixed64 is not UNSET:
            field_dict["fixed64"] = fixed64
        if fixed32 is not UNSET:
            field_dict["fixed32"] = fixed32
        if length_delimited is not UNSET:
            field_dict["lengthDelimited"] = length_delimited

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        varint = cast(list[int], d.pop("varint", UNSET))

        fixed64 = cast(list[int], d.pop("fixed64", UNSET))

        fixed32 = cast(list[int], d.pop("fixed32", UNSET))

        length_delimited = cast(list[str], d.pop("lengthDelimited", UNSET))

        field = cls(
            varint=varint,
            fixed64=fixed64,
            fixed32=fixed32,
            length_delimited=length_delimited,
        )

        field.additional_properties = d
        return field

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from . import commands_pb2 as _commands_pb2
from . import reassignment_commands_pb2 as _reassignment_commands_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SubmitRequest(_message.Message):
    __slots__ = ("commands",)
    COMMANDS_FIELD_NUMBER: _ClassVar[int]
    commands: _commands_pb2.Commands
    def __init__(self, commands: _Optional[_Union[_commands_pb2.Commands, _Mapping]] = ...) -> None: ...

class SubmitResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class SubmitReassignmentRequest(_message.Message):
    __slots__ = ("reassignment_commands",)
    REASSIGNMENT_COMMANDS_FIELD_NUMBER: _ClassVar[int]
    reassignment_commands: _reassignment_commands_pb2.ReassignmentCommands
    def __init__(self, reassignment_commands: _Optional[_Union[_reassignment_commands_pb2.ReassignmentCommands, _Mapping]] = ...) -> None: ...

class SubmitReassignmentResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ....protocol.v0 import sequencing_pb2 as _sequencing_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0

from __future__ import annotations

import argparse
from pathlib import Path

parser = argparse.ArgumentParser("_dazl")
parser.add_argument("-T", "--temp-dir")
parser.add_argument("--log-level", default="info")

subparsers = parser.add_subparsers(dest="command")

update_parser = subparsers.add_parser("update")
update_parser.add_argument("protopack")

generate_api_parser = subparsers.add_parser("generate-api")
generate_api_parser.add_argument("openapi_dir", help="Directory containing OpenAPI specifications")

args = parser.parse_args()

from . import _logging

_logging.initialize(args.log_level)

if args.command == "update":
    from . import update

    update.update(Path(args.protopack))
elif args.command == "generate-api":
    from . import generate_api

    generate_api.generate_api_clients(
        Path(args.openapi_dir),
        Path(__file__).parent.parent / "dazl" / "_gen_api",
    )



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ....crypto.v30 import crypto_pb2 as _crypto_pb2
from ....v30 import trace_context_pb2 as _trace_context_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ConnectToSequencerChannelRequest(_message.Message):
    __slots__ = ("metadata", "session_key", "session_key_acknowledgement", "payload", "trace_context")
    METADATA_FIELD_NUMBER: _ClassVar[int]
    SESSION_KEY_FIELD_NUMBER: _ClassVar[int]
    SESSION_KEY_ACKNOWLEDGEMENT_FIELD_NUMBER: _ClassVar[int]
    PAYLOAD_FIELD_NUMBER: _ClassVar[int]
    TRACE_CONTEXT_FIELD_NUMBER: _ClassVar[int]
    metadata: SequencerChannelMetadata
    session_key: SequencerChannelSessionKey
    session_key_acknowledgement: SequencerChannelSessionKeyAck
    payload: bytes
    trace_context: _trace_context_pb2.TraceContext
    def __init__(self, metadata: _Optional[_Union[SequencerChannelMetadata, _Mapping]] = ..., session_key: _Optional[_Union[SequencerChannelSessionKey, _Mapping]] = ..., session_key_acknowledgement: _Optional[_Union[SequencerChannelSessionKeyAck, _Mapping]] = ..., payload: _Optional[bytes] = ..., trace_context: _Optional[_Union[_trace_context_pb2.TraceContext, _Mapping]] = ...) -> None: ...

class ConnectToSequencerChannelResponse(_message.Message):
    __slots__ = ("connected", "session_key", "session_key_acknowledgement", "payload", "trace_context")
    CONNECTED_FIELD_NUMBER: _ClassVar[int]
    SESSION_KEY_FIELD_NUMBER: _ClassVar[int]
    SESSION_KEY_ACKNOWLEDGEMENT_FIELD_NUMBER: _ClassVar[int]
    PAYLOAD_FIELD_NUMBER: _ClassVar[int]
    TRACE_CONTEXT_FIELD_NUMBER: _ClassVar[int]
    connected: SequencerChannelConnectedToAllEndpoints
    session_key: SequencerChannelSessionKey
    session_key_acknowledgement: SequencerChannelSessionKeyAck
    payload: bytes
    trace_context: _trace_context_pb2.TraceContext
    def __init__(self, connected: _Optional[_Union[SequencerChannelConnectedToAllEndpoints, _Mapping]] = ..., session_key: _Optional[_Union[SequencerChannelSessionKey, _Mapping]] = ..., session_key_acknowledgement: _Optional[_Union[SequencerChannelSessionKeyAck, _Mapping]] = ..., payload: _Optional[bytes] = ..., trace_context: _Optional[_Union[_trace_context_pb2.TraceContext, _Mapping]] = ...) -> None: ...

class PingRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class PingResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class SequencerChannelMetadata(_message.Message):
    __slots__ = ("channel_id", "initiating_member", "receiving_member")
    CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    INITIATING_MEMBER_FIELD_NUMBER: _ClassVar[int]
    RECEIVING_MEMBER_FIELD_NUMBER: _ClassVar[int]
    channel_id: str
    initiating_member: str
    receiving_member: str
    def __init__(self, channel_id: _Optional[str] = ..., initiating_member: _Optional[str] = ..., receiving_member: _Optional[str] = ...) -> None: ...

class SequencerChannelConnectedToAllEndpoints(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class SequencerChannelSessionKey(_message.Message):
    __slots__ = ("encrypted_session_key",)
    ENCRYPTED_SESSION_KEY_FIELD_NUMBER: _ClassVar[int]
    encrypted_session_key: _crypto_pb2.AsymmetricEncrypted
    def __init__(self, encrypted_session_key: _Optional[_Union[_crypto_pb2.AsymmetricEncrypted, _Mapping]] = ...) -> None: ...

class SequencerChannelSessionKeyAck(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ...crypto.v0 import crypto_pb2 as _crypto_pb2
from ..v0 import participant_transaction_pb2 as _participant_transaction_pb2
from ..v1 import participant_transaction_pb2 as _participant_transaction_pb2_1
from ..v2 import participant_transaction_pb2 as _participant_transaction_pb2_1_1
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ViewParticipantData(_message.Message):
    __slots__ = ("salt", "core_inputs", "created_core", "created_in_subview_archived_in_core", "resolved_keys", "action_description", "rollback_context")
    SALT_FIELD_NUMBER: _ClassVar[int]
    CORE_INPUTS_FIELD_NUMBER: _ClassVar[int]
    CREATED_CORE_FIELD_NUMBER: _ClassVar[int]
    CREATED_IN_SUBVIEW_ARCHIVED_IN_CORE_FIELD_NUMBER: _ClassVar[int]
    RESOLVED_KEYS_FIELD_NUMBER: _ClassVar[int]
    ACTION_DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    ROLLBACK_CONTEXT_FIELD_NUMBER: _ClassVar[int]
    salt: _crypto_pb2.Salt
    core_inputs: _containers.RepeatedCompositeFieldContainer[_participant_transaction_pb2_1.InputContract]
    created_core: _containers.RepeatedCompositeFieldContainer[_participant_transaction_pb2_1.CreatedContract]
    created_in_subview_archived_in_core: _containers.RepeatedScalarFieldContainer[str]
    resolved_keys: _containers.RepeatedCompositeFieldContainer[_participant_transaction_pb2.ViewParticipantData.ResolvedKey]
    action_description: _participant_transaction_pb2_1_1.ActionDescription
    rollback_context: _participant_transaction_pb2.ViewParticipantData.RollbackContext
    def __init__(self, salt: _Optional[_Union[_crypto_pb2.Salt, _Mapping]] = ..., core_inputs: _Optional[_Iterable[_Union[_participant_transaction_pb2_1.InputContract, _Mapping]]] = ..., created_core: _Optional[_Iterable[_Union[_participant_transaction_pb2_1.CreatedContract, _Mapping]]] = ..., created_in_subview_archived_in_core: _Optional[_Iterable[str]] = ..., resolved_keys: _Optional[_Iterable[_Union[_participant_transaction_pb2.ViewParticipantData.ResolvedKey, _Mapping]]] = ..., action_description: _Optional[_Union[_participant_transaction_pb2_1_1.ActionDescription, _Mapping]] = ..., rollback_context: _Optional[_Union[_participant_transaction_pb2.ViewParticipantData.RollbackContext, _Mapping]] = ...) -> None: ...

class ActionDescription(_message.Message):
    __slots__ = ("create", "exercise", "fetch", "lookup_by_key")
    class ExerciseActionDescription(_message.Message):
        __slots__ = ("input_contract_id", "choice", "chosen_value", "actors", "by_key", "node_seed", "version", "failed", "interface_id", "template_id", "package_preference")
        INPUT_CONTRACT_ID_FIELD_NUMBER: _ClassVar[int]
        CHOICE_FIELD_NUMBER: _ClassVar[int]
        CHOSEN_VALUE_FIELD_NUMBER: _ClassVar[int]
        ACTORS_FIELD_NUMBER: _ClassVar[int]
        BY_KEY_FIELD_NUMBER: _ClassVar[int]
        NODE_SEED_FIELD_NUMBER: _ClassVar[int]
        VERSION_FIELD_NUMBER: _ClassVar[int]
        FAILED_FIELD_NUMBER: _ClassVar[int]
        INTERFACE_ID_FIELD_NUMBER: _ClassVar[int]
        TEMPLATE_ID_FIELD_NUMBER: _ClassVar[int]
        PACKAGE_PREFERENCE_FIELD_NUMBER: _ClassVar[int]
        input_contract_id: str
        choice: str
        chosen_value: bytes
        actors: _containers.RepeatedScalarFieldContainer[str]
        by_key: bool
        node_seed: bytes
        version: str
        failed: bool
        interface_id: str
        template_id: str
        package_preference: _containers.RepeatedScalarFieldContainer[str]
        def __init__(self, input_contract_id: _Optional[str] = ..., choice: _Optional[str] = ..., chosen_value: _Optional[bytes] = ..., actors: _Optional[_Iterable[str]] = ..., by_key: bool = ..., node_seed: _Optional[bytes] = ..., version: _Optional[str] = ..., failed: bool = ..., interface_id: _Optional[str] = ..., template_id: _Optional[str] = ..., package_preference: _Optional[_Iterable[str]] = ...) -> None: ...
    CREATE_FIELD_NUMBER: _ClassVar[int]
    EXERCISE_FIELD_NUMBER: _ClassVar[int]
    FETCH_FIELD_NUMBER: _ClassVar[int]
    LOOKUP_BY_KEY_FIELD_NUMBER: _ClassVar[int]
    create: _participant_transaction_pb2.ActionDescription.CreateActionDescription
    exercise: ActionDescription.ExerciseActionDescription
    fetch: _participant_transaction_pb2_1.ActionDescription.FetchActionDescription
    lookup_by_key: _participant_transaction_pb2_1.ActionDescription.LookupByKeyActionDescription
    def __init__(self, create: _Optional[_Union[_participant_transaction_pb2.ActionDescription.CreateActionDescription, _Mapping]] = ..., exercise: _Optional[_Union[ActionDescription.ExerciseActionDescription, _Mapping]] = ..., fetch: _Optional[_Union[_participant_transaction_pb2_1.ActionDescription.FetchActionDescription, _Mapping]] = ..., lookup_by_key: _Optional[_Union[_participant_transaction_pb2_1.ActionDescription.LookupByKeyActionDescription, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ....health.admin.v0 import status_service_pb2 as _status_service_pb2
from ....health.admin.v1 import status_service_pb2 as _status_service_pb2_1
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ParticipantStatusRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ConnectedDomain(_message.Message):
    __slots__ = ("domain_id", "healthy")
    DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
    HEALTHY_FIELD_NUMBER: _ClassVar[int]
    domain_id: str
    healthy: bool
    def __init__(self, domain_id: _Optional[str] = ..., healthy: bool = ...) -> None: ...

class ParticipantStatusResponse(_message.Message):
    __slots__ = ("status", "unavailable", "failure")
    class ParticipantStatusResponseStatus(_message.Message):
        __slots__ = ("common_status", "connected_domains", "active", "supported_protocol_versions")
        COMMON_STATUS_FIELD_NUMBER: _ClassVar[int]
        CONNECTED_DOMAINS_FIELD_NUMBER: _ClassVar[int]
        ACTIVE_FIELD_NUMBER: _ClassVar[int]
        SUPPORTED_PROTOCOL_VERSIONS_FIELD_NUMBER: _ClassVar[int]
        common_status: _status_service_pb2_1.Status
        connected_domains: _containers.RepeatedCompositeFieldContainer[ConnectedDomain]
        active: bool
        supported_protocol_versions: _containers.RepeatedScalarFieldContainer[int]
        def __init__(self, common_status: _Optional[_Union[_status_service_pb2_1.Status, _Mapping]] = ..., connected_domains: _Optional[_Iterable[_Union[ConnectedDomain, _Mapping]]] = ..., active: bool = ..., supported_protocol_versions: _Optional[_Iterable[int]] = ...) -> None: ...
    STATUS_FIELD_NUMBER: _ClassVar[int]
    UNAVAILABLE_FIELD_NUMBER: _ClassVar[int]
    FAILURE_FIELD_NUMBER: _ClassVar[int]
    status: ParticipantStatusResponse.ParticipantStatusResponseStatus
    unavailable: _status_service_pb2.NodeStatus.NotInitialized
    failure: _status_service_pb2_1.Failure
    def __init__(self, status: _Optional[_Union[ParticipantStatusResponse.ParticipantStatusResponseStatus, _Mapping]] = ..., unavailable: _Optional[_Union[_status_service_pb2.NodeStatus.NotInitialized, _Mapping]] = ..., failure: _Optional[_Union[_status_service_pb2_1.Failure, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

from .interactive_submission_common_data_pb2 import GlobalKey
from .interactive_submission_service_pb2 import CostEstimation, CostEstimationHints, DamlTransaction, ExecuteSubmissionAndWaitForTransactionRequest, ExecuteSubmissionAndWaitForTransactionResponse, ExecuteSubmissionAndWaitRequest, ExecuteSubmissionAndWaitResponse, ExecuteSubmissionRequest, ExecuteSubmissionResponse, GetPreferredPackageVersionRequest, GetPreferredPackageVersionResponse, GetPreferredPackagesRequest, GetPreferredPackagesResponse, HashingSchemeVersion, Metadata, MinLedgerTime, PackagePreference, PackageVettingRequirement, PartySignatures, PrepareSubmissionRequest, PrepareSubmissionResponse, PreparedTransaction, SinglePartySignatures
from .interactive_submission_service_pb2_grpc import InteractiveSubmissionServiceStub

__all__ = [
    "CostEstimation",
    "CostEstimationHints",
    "DamlTransaction",
    "ExecuteSubmissionAndWaitForTransactionRequest",
    "ExecuteSubmissionAndWaitForTransactionResponse",
    "ExecuteSubmissionAndWaitRequest",
    "ExecuteSubmissionAndWaitResponse",
    "ExecuteSubmissionRequest",
    "ExecuteSubmissionResponse",
    "GetPreferredPackageVersionRequest",
    "GetPreferredPackageVersionResponse",
    "GetPreferredPackagesRequest",
    "GetPreferredPackagesResponse",
    "GlobalKey",
    "HashingSchemeVersion",
    "InteractiveSubmissionServiceStub",
    "Metadata",
    "MinLedgerTime",
    "PackagePreference",
    "PackageVettingRequirement",
    "PartySignatures",
    "PrepareSubmissionRequest",
    "PrepareSubmissionResponse",
    "PreparedTransaction",
    "SinglePartySignatures",
]



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ....protocol.v30 import topology_pb2 as _topology_pb2
from . import common_pb2 as _common_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class InitIdRequest(_message.Message):
    __slots__ = ("identifier", "namespace", "namespace_delegations")
    IDENTIFIER_FIELD_NUMBER: _ClassVar[int]
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    NAMESPACE_DELEGATIONS_FIELD_NUMBER: _ClassVar[int]
    identifier: str
    namespace: str
    namespace_delegations: _containers.RepeatedCompositeFieldContainer[_topology_pb2.SignedTopologyTransaction]
    def __init__(self, identifier: _Optional[str] = ..., namespace: _Optional[str] = ..., namespace_delegations: _Optional[_Iterable[_Union[_topology_pb2.SignedTopologyTransaction, _Mapping]]] = ...) -> None: ...

class InitIdResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetIdResponse(_message.Message):
    __slots__ = ("initialized", "unique_identifier")
    INITIALIZED_FIELD_NUMBER: _ClassVar[int]
    UNIQUE_IDENTIFIER_FIELD_NUMBER: _ClassVar[int]
    initialized: bool
    unique_identifier: str
    def __init__(self, initialized: bool = ..., unique_identifier: _Optional[str] = ...) -> None: ...

class GetOnboardingTransactionsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetOnboardingTransactionsResponse(_message.Message):
    __slots__ = ("transactions",)
    TRANSACTIONS_FIELD_NUMBER: _ClassVar[int]
    transactions: _common_pb2.TopologyTransactions
    def __init__(self, transactions: _Optional[_Union[_common_pb2.TopologyTransactions, _Mapping]] = ...) -> None: ...

class GetIdRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class CurrentTimeRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class CurrentTimeResponse(_message.Message):
    __slots__ = ("current_time",)
    CURRENT_TIME_FIELD_NUMBER: _ClassVar[int]
    current_time: int
    def __init__(self, current_time: _Optional[int] = ...) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/participant/v30/party_management_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/admin/participant/v30/party_management_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import acs_import_pb2 as com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_acs__import__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nLcom/digitalasset/canton/admin/participant/v30/party_management_service.proto\x12-com.digitalasset.canton.admin.participant.v30\x1a>com/digitalasset/canton/admin/participant/v30/acs_import.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb6\x02\n\x14\x41\x64\x64PartyAsyncRequest\x12\x19\n\x08party_id\x18\x01 \x01(\tR\x07partyId\x12\'\n\x0fsynchronizer_id\x18\x02 \x01(\tR\x0esynchronizerId\x12\x34\n\x16source_participant_uid\x18\x03 \x01(\tR\x14sourceParticipantUid\x12\'\n\x0ftopology_serial\x18\x04 \x01(\rR\x0etopologySerial\x12{\n\x16participant_permission\x18\x05 \x01(\x0e\x32\x44.com.digitalasset.canton.admin.participant.v30.ParticipantPermissionR\x15participantPermission\"H\n\x15\x41\x64\x64PartyAsyncResponse\x12/\n\x14\x61\x64\x64_party_request_id\x18\x01 \x01(\tR\x11\x61\x64\x64PartyRequestId\"K\n\x18GetAddPartyStatusRequest\x12/\n\x14\x61\x64\x64_party_request_id\x18\x01 \x01(\tR\x11\x61\x64\x64PartyRequestId\"\x93\x17\n\x19GetAddPartyStatusResponse\x12\x19\n\x08party_id\x18\x01 \x01(\tR\x07partyId\x12\'\n\x0fsynchronizer_id\x18\x02 \x01(\tR\x0esynchronizerId\x12\x34\n\x16source_participant_uid\x18\x03 \x01(\tR\x14sourceParticipantUid\x12\x34\n\x16target_participant_uid\x18\x04 \x01(\tR\x14targetParticipantUid\x12\'\n\x0ftopology_serial\x18\x05 \x01(\rR\x0etopologySerial\x12{\n\x16participant_permission\x18\x06 \x01(\x0e\x32\x44.com.digitalasset.canton.admin.participant.v30.ParticipantPermissionR\x15participantPermission\x12g\n\x06status\x18\x07 \x01(\x0b\x32O.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusResponse.StatusR\x06status\x1a\xb6\x13\n\x06Status\x12\x92\x01\n\x12proposal_processed\x18\x01 \x01(\x0b\x32\x61.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusResponse.Status.ProposalProcessedH\x00R\x11proposalProcessed\x12\x92\x01\n\x12\x61greement_accepted\x18\x02 \x01(\x0b\x32\x61.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusResponse.Status.AgreementAcceptedH\x00R\x11\x61greementAccepted\x12\x95\x01\n\x13topology_authorized\x18\x03 \x01(\x0b\x32\x62.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusResponse.Status.TopologyAuthorizedH\x00R\x12topologyAuthorized\x12\x9e\x01\n\x16\x63onnection_established\x18\x04 \x01(\x0b\x32\x65.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusResponse.Status.ConnectionEstablishedH\x00R\x15\x63onnectionEstablished\x12\x89\x01\n\x0freplicating_acs\x18\x05 \x01(\x0b\x32^.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusResponse.Status.ReplicatingAcsH\x00R\x0ereplicatingAcs\x12\x96\x01\n\x14\x66ully_replicated_acs\x18\x06 \x01(\x0b\x32\x62.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusResponse.Status.FullyReplicatedAcsH\x00R\x12\x66ullyReplicatedAcs\x12y\n\tcompleted\x18\x07 \x01(\x0b\x32Y.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusResponse.Status.CompletedH\x00R\tcompleted\x12m\n\x05\x65rror\x18\x08 \x01(\x0b\x32U.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusResponse.Status.ErrorH\x00R\x05\x65rror\x12\x82\x01\n\x0c\x64isconnected\x18\t \x01(\x0b\x32\\.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusResponse.Status.DisconnectedH\x00R\x0c\x64isconnected\x1a\x13\n\x11ProposalProcessed\x1a\x38\n\x11\x41greementAccepted\x12#\n\rsequencer_uid\x18\x01 \x01(\tR\x0csequencerUid\x1as\n\x12TopologyAuthorized\x12#\n\rsequencer_uid\x18\x01 \x01(\tR\x0csequencerUid\x12\x38\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x1av\n\x15\x43onnectionEstablished\x12#\n\rsequencer_uid\x18\x01 \x01(\tR\x0csequencerUid\x12\x38\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x1a\xa2\x01\n\x0eReplicatingAcs\x12#\n\rsequencer_uid\x18\x01 \x01(\tR\x0csequencerUid\x12\x38\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12\x31\n\x14\x63ontracts_replicated\x18\x03 \x01(\rR\x13\x63ontractsReplicated\x1a\xa6\x01\n\x12\x46ullyReplicatedAcs\x12#\n\rsequencer_uid\x18\x01 \x01(\tR\x0csequencerUid\x12\x38\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12\x31\n\x14\x63ontracts_replicated\x18\x03 \x01(\rR\x13\x63ontractsReplicated\x1a\x9d\x01\n\tCompleted\x12#\n\rsequencer_uid\x18\x01 \x01(\tR\x0csequencerUid\x12\x38\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12\x31\n\x14\x63ontracts_replicated\x18\x03 \x01(\rR\x13\x63ontractsReplicated\x1a\xb1\x01\n\x05\x45rror\x12#\n\rerror_message\x18\x01 \x01(\tR\x0c\x65rrorMessage\x12\x82\x01\n\x15status_prior_to_error\x18\x02 \x01(\x0b\x32O.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusResponse.StatusR\x12statusPriorToError\x1a\xcc\x01\n\x0c\x44isconnected\x12-\n\x12\x64isconnect_message\x18\x01 \x01(\tR\x11\x64isconnectMessage\x12\x8c\x01\n\x1astatus_prior_to_disconnect\x18\x02 \x01(\x0b\x32O.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusResponse.StatusR\x17statusPriorToDisconnectB\x08\n\x06status\"\xa1\x02\n\x15\x45xportPartyAcsRequest\x12\x19\n\x08party_id\x18\x01 \x01(\tR\x07partyId\x12\'\n\x0fsynchronizer_id\x18\x02 \x01(\tR\x0esynchronizerId\x12\x34\n\x16target_participant_uid\x18\x03 \x01(\tR\x14targetParticipantUid\x12\x34\n\x16\x62\x65gin_offset_exclusive\x18\x04 \x01(\x03R\x14\x62\x65ginOffsetExclusive\x12X\n\x1bwait_for_activation_timeout\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationR\x18waitForActivationTimeout\".\n\x16\x45xportPartyAcsResponse\x12\x14\n\x05\x63hunk\x18\x01 \x01(\x0cR\x05\x63hunk\"\xfb\x02\n\x15ImportPartyAcsRequest\x12!\n\x0c\x61\x63s_snapshot\x18\x01 \x01(\x0cR\x0b\x61\x63sSnapshot\x12,\n\x12workflow_id_prefix\x18\x02 \x01(\tR\x10workflowIdPrefix\x12s\n\x14\x63ontract_import_mode\x18\x03 \x01(\x0e\x32\x41.com.digitalasset.canton.admin.participant.v30.ContractImportModeR\x12\x63ontractImportMode\x12\x9b\x01\n\"representative_package_id_override\x18\x04 \x01(\x0b\x32N.com.digitalasset.canton.admin.participant.v30.RepresentativePackageIdOverrideR\x1frepresentativePackageIdOverride\"\x18\n\x16ImportPartyAcsResponse\"\x9d\x01\n\"GetHighestOffsetByTimestampRequest\x12\'\n\x0fsynchronizer_id\x18\x01 \x01(\tR\x0esynchronizerId\x12\x38\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12\x14\n\x05\x66orce\x18\x03 \x01(\x08R\x05\x66orce\"J\n#GetHighestOffsetByTimestampResponse\x12#\n\rledger_offset\x18\x01 \x01(\x03R\x0cledgerOffset\"\xf5\x01\n\x1f\x43learPartyOnboardingFlagRequest\x12\x19\n\x08party_id\x18\x01 \x01(\tR\x07partyId\x12\'\n\x0fsynchronizer_id\x18\x02 \x01(\tR\x0esynchronizerId\x12\x34\n\x16\x62\x65gin_offset_exclusive\x18\x03 \x01(\x03R\x14\x62\x65ginOffsetExclusive\x12X\n\x1bwait_for_activation_timeout\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationR\x18waitForActivationTimeout\"\xb8\x01\n ClearPartyOnboardingFlagResponse\x12\x1c\n\tonboarded\x18\x01 \x01(\x08R\tonboarded\x12Y\n\x18\x65\x61rliest_retry_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00R\x16\x65\x61rliestRetryTimestamp\x88\x01\x01\x42\x1b\n\x19_earliest_retry_timestamp*\xb7\x01\n\x15ParticipantPermission\x12&\n\"PARTICIPANT_PERMISSION_UNSPECIFIED\x10\x00\x12%\n!PARTICIPANT_PERMISSION_SUBMISSION\x10\x01\x12\'\n#PARTICIPANT_PERMISSION_CONFIRMATION\x10\x02\x12&\n\"PARTICIPANT_PERMISSION_OBSERVATION\x10\x03\x32\xa7\x08\n\x16PartyManagementService\x12\x9a\x01\n\rAddPartyAsync\x12\x43.com.digitalasset.canton.admin.participant.v30.AddPartyAsyncRequest\x1a\x44.com.digitalasset.canton.admin.participant.v30.AddPartyAsyncResponse\x12\xa6\x01\n\x11GetAddPartyStatus\x12G.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusRequest\x1aH.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusResponse\x12\x9f\x01\n\x0e\x45xportPartyAcs\x12\x44.com.digitalasset.canton.admin.participant.v30.ExportPartyAcsRequest\x1a\x45.com.digitalasset.canton.admin.participant.v30.ExportPartyAcsResponse0\x01\x12\x9f\x01\n\x0eImportPartyAcs\x12\x44.com.digitalasset.canton.admin.participant.v30.ImportPartyAcsRequest\x1a\x45.com.digitalasset.canton.admin.participant.v30.ImportPartyAcsResponse(\x01\x12\xc4\x01\n\x1bGetHighestOffsetByTimestamp\x12Q.com.digitalasset.canton.admin.participant.v30.GetHighestOffsetByTimestampRequest\x1aR.com.digitalasset.canton.admin.participant.v30.GetHighestOffsetByTimestampResponse\x12\xbb\x01\n\x18\x43learPartyOnboardingFlag\x12N.com.digitalasset.canton.admin.participant.v30.ClearPartyOnboardingFlagRequest\x1aO.com.digitalasset.canton.admin.participant.v30.ClearPartyOnboardingFlagResponseB^Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.participant.v30.party_management_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30'
  _globals['_PARTICIPANTPERMISSION']._serialized_start=5106
  _globals['_PARTICIPANTPERMISSION']._serialized_end=5289
  _globals['_ADDPARTYASYNCREQUEST']._serialized_start=257
  _globals['_ADDPARTYASYNCREQUEST']._serialized_end=567
  _globals['_ADDPARTYASYNCRESPONSE']._serialized_start=569
  _globals['_ADDPARTYASYNCRESPONSE']._serialized_end=641
  _globals['_GETADDPARTYSTATUSREQUEST']._serialized_start=643
  _globals['_GETADDPARTYSTATUSREQUEST']._serialized_end=718
  _globals['_GETADDPARTYSTATUSRESPONSE']._serialized_start=721
  _globals['_GETADDPARTYSTATUSRESPONSE']._serialized_end=3684
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS']._serialized_start=1198
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS']._serialized_end=3684
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_PROPOSALPROCESSED']._serialized_start=2479
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_PROPOSALPROCESSED']._serialized_end=2498
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_AGREEMENTACCEPTED']._serialized_start=2500
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_AGREEMENTACCEPTED']._serialized_end=2556
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_TOPOLOGYAUTHORIZED']._serialized_start=2558
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_TOPOLOGYAUTHORIZED']._serialized_end=2673
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_CONNECTIONESTABLISHED']._serialized_start=2675
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_CONNECTIONESTABLISHED']._serialized_end=2793
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_REPLICATINGACS']._serialized_start=2796
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_REPLICATINGACS']._serialized_end=2958
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_FULLYREPLICATEDACS']._serialized_start=2961
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_FULLYREPLICATEDACS']._serialized_end=3127
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_COMPLETED']._serialized_start=3130
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_COMPLETED']._serialized_end=3287
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_ERROR']._serialized_start=3290
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_ERROR']._serialized_end=3467
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_DISCONNECTED']._serialized_start=3470
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_DISCONNECTED']._serialized_end=3674
  _globals['_EXPORTPARTYACSREQUEST']._serialized_start=3687
  _globals['_EXPORTPARTYACSREQUEST']._serialized_end=3976
  _globals['_EXPORTPARTYACSRESPONSE']._serialized_start=3978
  _globals['_EXPORTPARTYACSRESPONSE']._serialized_end=4024
  _globals['_IMPORTPARTYACSREQUEST']._serialized_start=4027
  _globals['_IMPORTPARTYACSREQUEST']._serialized_end=4406
  _globals['_IMPORTPARTYACSRESPONSE']._serialized_start=4408
  _globals['_IMPORTPARTYACSRESPONSE']._serialized_end=4432
  _globals['_GETHIGHESTOFFSETBYTIMESTAMPREQUEST']._serialized_start=4435
  _globals['_GETHIGHESTOFFSETBYTIMESTAMPREQUEST']._serialized_end=4592
  _globals['_GETHIGHESTOFFSETBYTIMESTAMPRESPONSE']._serialized_start=4594
  _globals['_GETHIGHESTOFFSETBYTIMESTAMPRESPONSE']._serialized_end=4668
  _globals['_CLEARPARTYONBOARDINGFLAGREQUEST']._serialized_start=4671
  _globals['_CLEARPARTYONBOARDINGFLAGREQUEST']._serialized_end=4916
  _globals['_CLEARPARTYONBOARDINGFLAGRESPONSE']._serialized_start=4919
  _globals['_CLEARPARTYONBOARDINGFLAGRESPONSE']._serialized_end=5103
  _globals['_PARTYMANAGEMENTSERVICE']._serialized_start=5292
  _globals['_PARTYMANAGEMENTSERVICE']._serialized_end=6355
# @@protoc_insertion_point(module_scope)
